import requests
from fastapi import Depends, APIRouter, HTTPException, status
from fastapi.responses import JSONResponse

from api import get_conn
from util.auth import check_auth
from model.settings import settings
from model.wapi.cntl import APIToken, Mgr

router = APIRouter(
    prefix="/api/apliste",
    tags=["apliste"]
)
js_mods = ['ap_list']


@router.get("/json")
def get_data(token: APIToken = Depends(check_auth), conn=Depends(get_conn)):
    user = Mgr.check_token(conn, token)
    if not user.has_permission(conn, 'nd.ro:device'):
        raise HTTPException(status_code=status.HTTP_400_BAD_REQUEST, detail="Insufficient permission")
    data = requests.get(settings.aplist_server_url + '/json',
                        cert=(settings.aplist_cert, settings.aplist_key),
                        verify=settings.aplist_ca,
                        ).json()
    return JSONResponse(data)
